==> selenium-devtools-v118-4.14.0-sources.jar: org/openqa/selenium/devtools/v118/css/model/InheritedPseudoElementMatches.java <==
package org.openqa.selenium.devtools.v118.css.model;

import org.openqa.selenium.Beta;
import org.openqa.selenium.json.JsonInput;

/**
 * Inherited pseudo element matches from pseudos of an ancestor node.
 */
public class InheritedPseudoElementMatches {

    private final java.util.List<org.openqa.selenium.devtools.v118.css.model.PseudoElementMatches> pseudoElements;

    public InheritedPseudoElementMatches(java.util.List<org.openqa.selenium.devtools.v118.css.model.PseudoElementMatches> pseudoElements) {
        this.pseudoElements = java.util.Objects.requireNonNull(pseudoElements, "pseudoElements is required");
    }

    /**
     * Matches of pseudo styles from the pseudos of an ancestor node.
     */
    public java.util.List<org.openqa.selenium.devtools.v118.css.model.PseudoElementMatches> getPseudoElements() {
        return pseudoElements;
    }

    private static InheritedPseudoElementMatches fromJson(JsonInput input) {
        java.util.List<org.openqa.selenium.devtools.v118.css.model.PseudoElementMatches> pseudoElements = null;
        input.beginObject();
        while (input.hasNext()) {
            switch(input.nextName()) {
                case "pseudoElements":
                    pseudoElements = input.read(new com.google.common.reflect.TypeToken<java.util.List<org.openqa.selenium.devtools.v118.css.model.PseudoElementMatches>>() {
                    }.getType());
                    break;
                default:
                    input.skipValue();
                    break;
            }
        }
        input.endObject();
        return new InheritedPseudoElementMatches(pseudoElements);
    }
}

==> selenium-devtools-v118-4.16.1-sources.jar: org/openqa/selenium/devtools/v118/css/model/InheritedPseudoElementMatches.java <==
package org.openqa.selenium.devtools.v118.css.model;

import org.openqa.selenium.Beta;
import org.openqa.selenium.json.JsonInput;

/**
 * Inherited pseudo element matches from pseudos of an ancestor node.
 */
public class InheritedPseudoElementMatches {

    private final java.util.List<org.openqa.selenium.devtools.v118.css.model.PseudoElementMatches> pseudoElements;

    public InheritedPseudoElementMatches(java.util.List<org.openqa.selenium.devtools.v118.css.model.PseudoElementMatches> pseudoElements) {
        this.pseudoElements = java.util.Objects.requireNonNull(pseudoElements, "pseudoElements is required");
    }

    /**
     * Matches of pseudo styles from the pseudos of an ancestor node.
     */
    public java.util.List<org.openqa.selenium.devtools.v118.css.model.PseudoElementMatches> getPseudoElements() {
        return pseudoElements;
    }

    private static InheritedPseudoElementMatches fromJson(JsonInput input) {
        java.util.List<org.openqa.selenium.devtools.v118.css.model.PseudoElementMatches> pseudoElements = null;
        input.beginObject();
        while (input.hasNext()) {
            switch(input.nextName()) {
                case "pseudoElements":
                    pseudoElements = input.readArray(org.openqa.selenium.devtools.v118.css.model.PseudoElementMatches.class);
                    break;
                default:
                    input.skipValue();
                    break;
            }
        }
        input.endObject();
        return new InheritedPseudoElementMatches(pseudoElements);
    }
}
